/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_6ivbheIu);
  numBytes += sLine_init(&sLine_bmMFvyAf);
  numBytes += sTabhead_init(&sTabhead_ADCzZc2Y, &hTable_NNeanlsA);
  numBytes += sTabread_init(&sTabread_slNEcyeN, &hTable_NNeanlsA, false);
  numBytes += sTabread_init(&sTabread_iCoRGlk3, &hTable_NNeanlsA, false);
  numBytes += sLine_init(&sLine_h5Q1BSNL);
  numBytes += sLine_init(&sLine_tAJeIkPX);
  numBytes += sLine_init(&sLine_mQo83Lin);
  numBytes += sTabhead_init(&sTabhead_WpOKz267, &hTable_MLxkKUal);
  numBytes += sTabread_init(&sTabread_XiqByUG5, &hTable_MLxkKUal, false);
  numBytes += sTabread_init(&sTabread_Q9w7b32A, &hTable_MLxkKUal, false);
  numBytes += sLine_init(&sLine_YywvXSKQ);
  numBytes += sTabwrite_init(&sTabwrite_6fHMxiS0, &hTable_NNeanlsA);
  numBytes += sTabwrite_init(&sTabwrite_o8lqFoYA, &hTable_MLxkKUal);
  numBytes += sRPole_init(&sRPole_8omGyVtk);
  numBytes += sRPole_init(&sRPole_duIWbG5J);
  numBytes += sRPole_init(&sRPole_HEcqSUYW);
  numBytes += sDel1_init(&sDel1_oyIuzZKS);
  numBytes += sLine_init(&sLine_uNYzm505);
  numBytes += sLine_init(&sLine_6zmXEmRD);
  numBytes += sRPole_init(&sRPole_IykCaCqH);
  numBytes += sRPole_init(&sRPole_G7HcrwZQ);
  numBytes += sRPole_init(&sRPole_HOmwoNzO);
  numBytes += sDel1_init(&sDel1_PHEEee2n);
  numBytes += sLine_init(&sLine_do6qq7OJ);
  numBytes += sLine_init(&sLine_k9p90COK);
  numBytes += sLine_init(&sLine_QmdJoJrp);
  numBytes += sLine_init(&sLine_6whyL3Ji);
  numBytes += cVar_init_f(&cVar_jf8yzHoY, 0.0f);
  numBytes += cVar_init_f(&cVar_BeK9uT5j, 0.0f);
  numBytes += cVar_init_f(&cVar_xkumXSLm, 0.0f);
  numBytes += cVar_init_f(&cVar_Kt2VGMSu, 0.0f);
  numBytes += cSlice_init(&cSlice_BNMlPxFc, 1, -1);
  numBytes += cVar_init_f(&cVar_4Jv0pIgZ, 0.5f);
  numBytes += cSlice_init(&cSlice_JPpzNtYt, 1, -1);
  numBytes += cVar_init_f(&cVar_LwrNG9rU, 0.2f);
  numBytes += cSlice_init(&cSlice_0ALBEpBZ, 1, -1);
  numBytes += cVar_init_f(&cVar_jw1W2xtV, 500.0f);
  numBytes += cSlice_init(&cSlice_PL8p4tq4, 1, -1);
  numBytes += cVar_init_f(&cVar_d3NQzdva, 0.25f);
  numBytes += cDelay_init(this, &cDelay_JdJhPKco, 0.0f);
  numBytes += cDelay_init(this, &cDelay_rdSw2V2v, 0.0f);
  numBytes += hTable_init(&hTable_NNeanlsA, 256);
  numBytes += cDelay_init(this, &cDelay_RJl6USyL, 0.0f);
  numBytes += cDelay_init(this, &cDelay_D9tiVKD3, 0.0f);
  numBytes += hTable_init(&hTable_MLxkKUal, 256);
  numBytes += cVar_init_f(&cVar_sBdp9Qrb, 8000.0f);
  numBytes += cBinop_init(&cBinop_VgXNw3Lq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Q24J1kyF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TswgYJEX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_jQfWluNR, 8000.0f);
  numBytes += cBinop_init(&cBinop_sCBImVAG, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_n65ZNFvw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tbApJojA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MnvQBLa5, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NVgQci1y, 300.0f);
  numBytes += cBinop_init(&cBinop_nrNy9egC, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Qq2HDgiy, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_eu4fwQng, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_u5zZ1U1i, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_12khAXyZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m2gR5lFy, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_KrzHegp9, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_xWn2DdAV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jWQgr8Cc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Y3GsfxjC, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_CGcfobYe, 8000.0f);
  numBytes += cBinop_init(&cBinop_tYLJLabe, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_kIz15yLt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_czBardnj, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_v0qKr3R3, 8000.0f);
  numBytes += cBinop_init(&cBinop_RqXk7HFp, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_4LYFf03k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UOk0J5Aa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YdwtKnOs, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_qt9TPyFJ, 300.0f);
  numBytes += cBinop_init(&cBinop_LsGxICpX, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_0ztlcu6X, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WdoUL14E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1Ao51fKB, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_siGVLr3L, 1.0f);
  numBytes += cIf_init(&cIf_9lQgko5H, false);
  numBytes += cIf_init(&cIf_Q1dzeETv, false);
  numBytes += cVar_init_f(&cVar_aEJs6lFt, 0.0f);
  numBytes += cVar_init_f(&cVar_z1tnREq6, 0.0f);
  numBytes += cVar_init_f(&cVar_JBrQ2pCA, 60000.0f);
  numBytes += cVar_init_f(&cVar_Z3fjvmjt, 500.0f);
  numBytes += cSlice_init(&cSlice_4vd7eX79, 1, -1);
  numBytes += cSlice_init(&cSlice_GB9Eu735, 1, -1);
  numBytes += cVar_init_f(&cVar_GpyAKzaI, 0.0f);
  numBytes += cIf_init(&cIf_HxjtqIwd, false);
  numBytes += cBinop_init(&cBinop_6gPNhATH, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_OVKkmlx5, 120.0f);
  numBytes += cBinop_init(&cBinop_XQGmOUrH, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_yUd5KMPu, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_NNeanlsA);
  hTable_free(&hTable_MLxkKUal);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_NNeanlsA; // del-1011-delayL
    case 0xF057CB49: return &hTable_MLxkKUal; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sMNbOaxU_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q5LLOAi1_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dz6Dlqxy_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6J36Zb5O_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vc5n1j6I_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zG3Gzp8W_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QkiTDHAy_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AjJldCzf_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4tWP0zSz_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AqR5v8GT_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uAiWRJwW_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UYFiYAmS_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_jf8yzHoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ufb5Z3Uq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_BeK9uT5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IeSWgOi4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_xkumXSLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ijxVglpI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_Kt2VGMSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qd47qgGD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_DyZriiq0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BNMlPxFc, 0, m, &cSlice_BNMlPxFc_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_BNMlPxFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JYLXV9WP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JYLXV9WP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_4Jv0pIgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JYLXV9WP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_JYLXV9WP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4tWP0zSz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_2JsiVIc4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JPpzNtYt, 0, m, &cSlice_JPpzNtYt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5pV0dG1J_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_JPpzNtYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2qLVx0tv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2qLVx0tv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_LwrNG9rU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2qLVx0tv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_2qLVx0tv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QkiTDHAy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_N9D8pxU9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0ALBEpBZ, 0, m, &cSlice_0ALBEpBZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DyZriiq0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_0ALBEpBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fGNzVDGp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fGNzVDGp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_jw1W2xtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fGNzVDGp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_fGNzVDGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AqR5v8GT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_pWuZKubu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_T8qEyHcx_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_T8qEyHcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_sozQgNo7_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_P2EJo2OY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KA3eKavm_sendMessage(_c, 0, m);
  cMsg_HWUtQwxH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_jkaxk18H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3g7vK1dQ_sendMessage(_c, 0, m);
  cMsg_vJDi1PBz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_sozQgNo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RPGPRkvm_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_RPGPRkvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w7hGxpbK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mh0CqjqU_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_w7hGxpbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ri6nNmU6_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Mh0CqjqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fskpEC6h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ri6nNmU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZluioeE1_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fskpEC6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zrr79wMj_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_zrr79wMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tcekbRzq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ZluioeE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_P2EJo2OY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_tcekbRzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_jkaxk18H_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_13tY9fQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rgNL2Iy9_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rgNL2Iy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_CWN6rTPt_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_CWN6rTPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rswrpnXm_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rswrpnXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iisKJjWq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9atfBH7u_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_iisKJjWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_C8cR4o8p_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_9atfBH7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oTE5WElm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_C8cR4o8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cyN4s6K9_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_oTE5WElm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MwlvhSWA_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_MwlvhSWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gOV4ww6T_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_gOV4ww6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_811Lq830_sendMessage(_c, 0, m);
  cMsg_jTNeZT6Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_cyN4s6K9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5rnxzpOX_sendMessage(_c, 0, m);
  cMsg_qbylboUM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_5pV0dG1J_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PL8p4tq4, 0, m, &cSlice_PL8p4tq4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_N9D8pxU9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_PL8p4tq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DcJK8HfD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DcJK8HfD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_d3NQzdva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DcJK8HfD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_DcJK8HfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AjJldCzf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_pKSyRKKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VXgwOIDH_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_VXgwOIDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Ywt3UYgh_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_JdJhPKco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JdJhPKco, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rdSw2V2v, 0, m, &cDelay_rdSw2V2v_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JdJhPKco, 0, m, &cDelay_JdJhPKco_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6fHMxiS0, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_rdSw2V2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rdSw2V2v, m);
  cMsg_IQ4CvCL9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_lwE3nToq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_VaWr19E6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_w9zkJeM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sIWFK5PR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_NNeanlsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jgxAuDhJ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JdJhPKco, 2, m, &cDelay_JdJhPKco_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wni7Tmy3_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_sIWFK5PR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_NNeanlsA, 0, m, &hTable_NNeanlsA_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Ywt3UYgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_w9zkJeM7_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_IQ4CvCL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_NNeanlsA, 0, m, &hTable_NNeanlsA_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_wni7Tmy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JdJhPKco, 0, m, &cDelay_JdJhPKco_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_jgxAuDhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_rdSw2V2v, 2, m, &cDelay_rdSw2V2v_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_VaWr19E6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6fHMxiS0, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_TF3WKgJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oXu6AbHP_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_oXu6AbHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6ZlYxys8_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_RJl6USyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RJl6USyL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_D9tiVKD3, 0, m, &cDelay_D9tiVKD3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RJl6USyL, 0, m, &cDelay_RJl6USyL_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_o8lqFoYA, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_D9tiVKD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D9tiVKD3, m);
  cMsg_PISVCPTv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_3ATHdjAw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_7YhBOCNw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_Of01aiZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gNz5hF15_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_MLxkKUal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T09JLw0x_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RJl6USyL, 2, m, &cDelay_RJl6USyL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XGwaqj0I_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_gNz5hF15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_MLxkKUal, 0, m, &hTable_MLxkKUal_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_6ZlYxys8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Of01aiZ7_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_PISVCPTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_MLxkKUal, 0, m, &hTable_MLxkKUal_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_XGwaqj0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RJl6USyL, 0, m, &cDelay_RJl6USyL_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_T09JLw0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_D9tiVKD3, 2, m, &cDelay_D9tiVKD3_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_7YhBOCNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_o8lqFoYA, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_sBdp9Qrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VgXNw3Lq, HV_BINOP_MULTIPLY, 0, m, &cBinop_VgXNw3Lq_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_LWWlUsYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_G0jNiibm_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_G0jNiibm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n7j3vagJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_VgXNw3Lq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2SpVg8XE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Z3tDj3H3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VgXNw3Lq, HV_BINOP_MULTIPLY, 1, m, &cBinop_VgXNw3Lq_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_n7j3vagJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Z3tDj3H3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_2SpVg8XE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_BTdMnadb_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_BTdMnadb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ELOt4cNW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_TswgYJEX, m);
}

void Heavy_WSTD_DLAY::cBinop_ELOt4cNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Q24J1kyF, m);
}

void Heavy_WSTD_DLAY::cVar_jQfWluNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sCBImVAG, HV_BINOP_MULTIPLY, 0, m, &cBinop_sCBImVAG_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bgAnNKcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_h3CCJikJ_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_h3CCJikJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cBacsJS3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_sCBImVAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1F7M48aV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_GBAed7uL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sCBImVAG, HV_BINOP_MULTIPLY, 1, m, &cBinop_sCBImVAG_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_cBacsJS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GBAed7uL_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1F7M48aV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IvTr1Pgy_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IvTr1Pgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_EagP9NdC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tbApJojA, m);
}

void Heavy_WSTD_DLAY::cBinop_EagP9NdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_n65ZNFvw, m);
}

void Heavy_WSTD_DLAY::cBinop_yLCqbHWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_63TKV5fr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_63TKV5fr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_68NjHvr6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2rIoGBMB_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_NVgQci1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_VzoJk88G_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_9qqf5Dv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_H4po5inJ_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_H4po5inJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nrNy9egC, HV_BINOP_DIVIDE, 1, m, &cBinop_nrNy9egC_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_68NjHvr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Jphz34pt_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Jphz34pt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qq2HDgiy, m);
}

void Heavy_WSTD_DLAY::cMsg_Vo09yqmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Vkz51DlS_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Vkz51DlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yLCqbHWV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_2rIoGBMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MnvQBLa5, m);
}

void Heavy_WSTD_DLAY::cBinop_VzoJk88G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_38RigMer_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_38RigMer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nrNy9egC, HV_BINOP_DIVIDE, 0, m, &cBinop_nrNy9egC_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_nrNy9egC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vo09yqmu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_CDWhbFsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GetKtulG_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_GetKtulG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pywUEQ7G_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_eu4fwQng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LK3DZ7uI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_o2AT8vVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QO8Fra90_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_u5zZ1U1i, m);
}

void Heavy_WSTD_DLAY::cBinop_pywUEQ7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_12khAXyZ, m);
}

void Heavy_WSTD_DLAY::cMsg_LK3DZ7uI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_o2AT8vVf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QO8Fra90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_m2gR5lFy, m);
}

void Heavy_WSTD_DLAY::cMsg_jTUaqrlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zo0LVyUX_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_zo0LVyUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NIiD4lHO_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_KrzHegp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BqX9aQVj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_ydus6JTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qHWU7NPM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xWn2DdAV, m);
}

void Heavy_WSTD_DLAY::cBinop_NIiD4lHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_jWQgr8Cc, m);
}

void Heavy_WSTD_DLAY::cMsg_BqX9aQVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ydus6JTM_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_qHWU7NPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Y3GsfxjC, m);
}

void Heavy_WSTD_DLAY::cVar_CGcfobYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tYLJLabe, HV_BINOP_MULTIPLY, 0, m, &cBinop_tYLJLabe_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_oZyTLofJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1X9AZkpo_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_1X9AZkpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mKKab5dN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_tYLJLabe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_boWG2BGu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_D0AhBEmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tYLJLabe, HV_BINOP_MULTIPLY, 1, m, &cBinop_tYLJLabe_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_mKKab5dN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_D0AhBEmV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_boWG2BGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TXLHzFXi_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_TXLHzFXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lYs1u2yp_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_czBardnj, m);
}

void Heavy_WSTD_DLAY::cBinop_lYs1u2yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kIz15yLt, m);
}

void Heavy_WSTD_DLAY::cVar_v0qKr3R3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RqXk7HFp, HV_BINOP_MULTIPLY, 0, m, &cBinop_RqXk7HFp_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_nLhUUVP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Mfyh6Jkh_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_Mfyh6Jkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tDn3Vqwu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_RqXk7HFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_avYjc6lh_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_kOFgXuKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RqXk7HFp, HV_BINOP_MULTIPLY, 1, m, &cBinop_RqXk7HFp_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_tDn3Vqwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kOFgXuKV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_avYjc6lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gI16b6FR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_gI16b6FR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fcfJemAr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UOk0J5Aa, m);
}

void Heavy_WSTD_DLAY::cBinop_fcfJemAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4LYFf03k, m);
}

void Heavy_WSTD_DLAY::cBinop_rd6ceHGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MN0sUlNI_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_MN0sUlNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2KeHf4Pi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iMbltz1Y_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_qt9TPyFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_l1eOeyc2_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_swPZtLmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NWdgolne_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_NWdgolne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LsGxICpX, HV_BINOP_DIVIDE, 1, m, &cBinop_LsGxICpX_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_2KeHf4Pi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_B07vS4tw_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_B07vS4tw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0ztlcu6X, m);
}

void Heavy_WSTD_DLAY::cMsg_kfpYar8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Qz6HMaX8_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Qz6HMaX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rd6ceHGY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_iMbltz1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_YdwtKnOs, m);
}

void Heavy_WSTD_DLAY::cBinop_l1eOeyc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_5kRdKQyx_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_5kRdKQyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LsGxICpX, HV_BINOP_DIVIDE, 0, m, &cBinop_LsGxICpX_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_LsGxICpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kfpYar8U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_KA3eKavm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h5Q1BSNL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_3g7vK1dQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6ivbheIu, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_vJDi1PBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tAJeIkPX, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_HWUtQwxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YywvXSKQ, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_qbylboUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k9p90COK, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_811Lq830_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6zmXEmRD, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_5rnxzpOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6whyL3Ji, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_jTNeZT6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QmdJoJrp, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_hsKedEgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bmMFvyAf, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_ra5qEZYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mQo83Lin, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_AtDBmiHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uNYzm505, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_UqOoh2Dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_do6qq7OJ, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_siGVLr3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kI8O5KsC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4iWAuMUu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZleQHTYf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_kI8O5KsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_siGVLr3L, 1, m, &cVar_siGVLr3L_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_9lQgko5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_BeK9uT5j, 0, m, &cVar_BeK9uT5j_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_Q1dzeETv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_BeK9uT5j, 0, m, &cVar_BeK9uT5j_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_aEJs6lFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q1dzeETv, 0, m, &cIf_Q1dzeETv_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_z1tnREq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9lQgko5H, 0, m, &cIf_9lQgko5H_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_JBrQ2pCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XQGmOUrH, HV_BINOP_DIVIDE, 0, m, &cBinop_XQGmOUrH_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_Z3fjvmjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yUd5KMPu, HV_BINOP_MULTIPLY, 1, m, &cBinop_yUd5KMPu_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_VFpZFFs1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4vd7eX79, 0, m, &cSlice_4vd7eX79_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GB9Eu735, 0, m, &cSlice_GB9Eu735_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jVczoxPc_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X1nkq2bK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_4vd7eX79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_GpyAKzaI, 0, m, &cVar_GpyAKzaI_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_GpyAKzaI, 0, m, &cVar_GpyAKzaI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_GB9Eu735_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_6gPNhATH, HV_BINOP_NEQ, 1, m, &cBinop_6gPNhATH_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_GpyAKzaI, 1, m, &cVar_GpyAKzaI_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_6gPNhATH, HV_BINOP_NEQ, 1, m, &cBinop_6gPNhATH_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_GpyAKzaI, 1, m, &cVar_GpyAKzaI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_GpyAKzaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_gnIv5SEp_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_HxjtqIwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rv7jOLpW_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5X801T9F_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_5X801T9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GpyAKzaI, 0, m, &cVar_GpyAKzaI_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Rv7jOLpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6gPNhATH, HV_BINOP_NEQ, 1, m, &cBinop_6gPNhATH_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_6gPNhATH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HxjtqIwd, 1, m, &cIf_HxjtqIwd_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_jVczoxPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6gPNhATH, HV_BINOP_NEQ, 0, m, &cBinop_6gPNhATH_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_X1nkq2bK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HxjtqIwd, 0, m, &cIf_HxjtqIwd_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_OVKkmlx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_udhJSyqb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OXiX011J_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_YbbGdoL2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gbpubkrh_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3XtXFyD9_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HcvzLpPw_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k2qN8cXt_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VcxqN7WN_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FiF6YPXE_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cuAiHwdc_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2EYUo4j6_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Xu1mtCs_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hlca1ray_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xWW0ugil_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G6qfEkmC_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PGo7NNvL_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_Gbpubkrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PD80oTTO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_3XtXFyD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x80DeJw3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_HcvzLpPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PkGOW0tn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_k2qN8cXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gG4LKErQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_VcxqN7WN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qaQWlNMg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_FiF6YPXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yWgjLti3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_cuAiHwdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JmH4qmFE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_2EYUo4j6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_43K0CQk5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_0Xu1mtCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hRzAWGSE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_hlca1ray_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ekkeqHsl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_xWW0ugil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GLx9GYME_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_G6qfEkmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WIYreUG1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_PGo7NNvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M0LYhttJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_XQGmOUrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yUd5KMPu, HV_BINOP_MULTIPLY, 0, m, &cBinop_yUd5KMPu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_yUd5KMPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VFpZFFs1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_udhJSyqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XQGmOUrH, HV_BINOP_DIVIDE, 1, m, &cBinop_XQGmOUrH_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_OXiX011J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JBrQ2pCA, 0, m, &cVar_JBrQ2pCA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z3fjvmjt, 0, m, &cVar_Z3fjvmjt_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_jFsGmoSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JBrQ2pCA, 0, m, &cVar_JBrQ2pCA_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_48FSa1nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z3fjvmjt, 0, m, &cVar_Z3fjvmjt_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_PD80oTTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_x80DeJw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_PkGOW0tn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_gG4LKErQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_qaQWlNMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_yWgjLti3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_JmH4qmFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_43K0CQk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_hRzAWGSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ekkeqHsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_GLx9GYME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_WIYreUG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_M0LYhttJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48FSa1nq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jFsGmoSg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_qd47qgGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2JsiVIc4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Ufb5Z3Uq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2JsiVIc4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_EBHvKDnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Kt2VGMSu, 0, m, &cVar_Kt2VGMSu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_VvAcPbZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jf8yzHoY, 0, m, &cVar_jf8yzHoY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_awXBEHPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xkumXSLm, 0, m, &cVar_xkumXSLm_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_IeSWgOi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2JsiVIc4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_ijxVglpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2JsiVIc4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_gnIv5SEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z1tnREq6, 0, m, &cVar_z1tnREq6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ZleQHTYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JlkVT1su_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kZFkNTib_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4iWAuMUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ht6Ln7LF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FOdvPwHZ_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_FOdvPwHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aEJs6lFt, 0, m, &cVar_aEJs6lFt_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Ht6Ln7LF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q1dzeETv, 1, m, &cIf_Q1dzeETv_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_kZFkNTib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z1tnREq6, 0, m, &cVar_z1tnREq6_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_JlkVT1su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9lQgko5H, 1, m, &cIf_9lQgko5H_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_Dz6Dlqxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_EBHvKDnf_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_q5LLOAi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_VvAcPbZb_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_sMNbOaxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_awXBEHPt_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_vc5n1j6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aEJs6lFt, 0, m, &cVar_aEJs6lFt_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_AqR5v8GT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hsKedEgE_sendMessage(_c, 0, m);
  cMsg_ra5qEZYD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_AjJldCzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AtDBmiHj_sendMessage(_c, 0, m);
  cMsg_UqOoh2Dg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_4tWP0zSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pWuZKubu_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_UYFiYAmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4Jv0pIgZ, 0, m, &cVar_4Jv0pIgZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LwrNG9rU, 0, m, &cVar_LwrNG9rU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jw1W2xtV, 0, m, &cVar_jw1W2xtV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_d3NQzdva, 0, m, &cVar_d3NQzdva_sendMessage);
  cMsg_pKSyRKKv_sendMessage(_c, 0, m);
  cMsg_TF3WKgJj_sendMessage(_c, 0, m);
  cMsg_LWWlUsYT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sBdp9Qrb, 0, m, &cVar_sBdp9Qrb_sendMessage);
  cMsg_bgAnNKcT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jQfWluNR, 0, m, &cVar_jQfWluNR_sendMessage);
  cMsg_9qqf5Dv2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NVgQci1y, 0, m, &cVar_NVgQci1y_sendMessage);
  cMsg_oZyTLofJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CGcfobYe, 0, m, &cVar_CGcfobYe_sendMessage);
  cMsg_nLhUUVP1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_v0qKr3R3, 0, m, &cVar_v0qKr3R3_sendMessage);
  cMsg_swPZtLmM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qt9TPyFJ, 0, m, &cVar_qt9TPyFJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eu4fwQng, 0, m, &cVar_eu4fwQng_sendMessage);
  cMsg_CDWhbFsI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KrzHegp9, 0, m, &cVar_KrzHegp9_sendMessage);
  cMsg_jTUaqrlT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_QkiTDHAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_13tY9fQD_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_6J36Zb5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_siGVLr3L, 0, m, &cVar_siGVLr3L_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_uAiWRJwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OVKkmlx5, 0, m, &cVar_OVKkmlx5_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_zG3Gzp8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YbbGdoL2_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_6ivbheIu, VOf(Bf0));
    __hv_line_f(&sLine_bmMFvyAf, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_ADCzZc2Y, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_12khAXyZ, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_m2gR5lFy, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_u5zZ1U1i, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_slNEcyeN, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_iCoRGlk3, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_h5Q1BSNL, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_tAJeIkPX, VOf(Bf0));
    __hv_line_f(&sLine_mQo83Lin, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_WpOKz267, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_jWQgr8Cc, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Y3GsfxjC, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_xWn2DdAV, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_XiqByUG5, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_Q9w7b32A, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_YywvXSKQ, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_WdoUL14E, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_6fHMxiS0, VIf(Bf0));
    __hv_varread_f(&sVarf_1Ao51fKB, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_o8lqFoYA, VIf(Bf0));
    __hv_varread_f(&sVarf_TswgYJEX, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Q24J1kyF, VOf(Bf1));
    __hv_rpole_f(&sRPole_8omGyVtk, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_tbApJojA, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_n65ZNFvw, VOf(Bf1));
    __hv_rpole_f(&sRPole_duIWbG5J, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_MnvQBLa5, VOf(Bf0));
    __hv_rpole_f(&sRPole_HEcqSUYW, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_oyIuzZKS, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Qq2HDgiy, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_uNYzm505, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_6zmXEmRD, VOf(Bf0));
    __hv_varread_f(&sVarf_czBardnj, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_kIz15yLt, VOf(Bf4));
    __hv_rpole_f(&sRPole_IykCaCqH, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_UOk0J5Aa, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_4LYFf03k, VOf(Bf4));
    __hv_rpole_f(&sRPole_G7HcrwZQ, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_YdwtKnOs, VOf(Bf6));
    __hv_rpole_f(&sRPole_HOmwoNzO, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_PHEEee2n, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_0ztlcu6X, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_do6qq7OJ, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_k9p90COK, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_WdoUL14E, VIf(Bf6));
    __hv_line_f(&sLine_QmdJoJrp, VOf(Bf6));
    __hv_line_f(&sLine_6whyL3Ji, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_1Ao51fKB, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
