/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalRPole.h"
#include "HvSignalTabwrite.h"
#include "HvControlIf.h"
#include "HvControlCast.h"
#include "HvControlBinop.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"
#include "HvTable.h"
#include "HvSignalTabread.h"
#include "HvControlSlice.h"
#include "HvSignalVar.h"
#include "HvMath.h"
#include "HvControlDelay.h"
#include "HvControlVar.h"
#include "HvSignalDel1.h"
#include "HvControlUnop.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_jf8yzHoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BeK9uT5j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xkumXSLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Kt2VGMSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DyZriiq0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_BNMlPxFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4Jv0pIgZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JYLXV9WP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2JsiVIc4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_JPpzNtYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LwrNG9rU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2qLVx0tv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_N9D8pxU9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_0ALBEpBZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jw1W2xtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fGNzVDGp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pWuZKubu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T8qEyHcx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_P2EJo2OY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jkaxk18H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sozQgNo7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RPGPRkvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w7hGxpbK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mh0CqjqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ri6nNmU6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fskpEC6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zrr79wMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZluioeE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tcekbRzq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_13tY9fQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rgNL2Iy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CWN6rTPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rswrpnXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iisKJjWq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9atfBH7u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C8cR4o8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oTE5WElm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MwlvhSWA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gOV4ww6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cyN4s6K9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5pV0dG1J_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_PL8p4tq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_d3NQzdva_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_DcJK8HfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pKSyRKKv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VXgwOIDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JdJhPKco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_rdSw2V2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lwE3nToq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_w9zkJeM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_NNeanlsA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sIWFK5PR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ywt3UYgh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IQ4CvCL9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wni7Tmy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jgxAuDhJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VaWr19E6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TF3WKgJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oXu6AbHP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RJl6USyL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_D9tiVKD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3ATHdjAw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Of01aiZ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_MLxkKUal_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gNz5hF15_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6ZlYxys8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PISVCPTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XGwaqj0I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T09JLw0x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7YhBOCNw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sBdp9Qrb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LWWlUsYT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_G0jNiibm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VgXNw3Lq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z3tDj3H3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n7j3vagJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2SpVg8XE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BTdMnadb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ELOt4cNW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jQfWluNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bgAnNKcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_h3CCJikJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sCBImVAG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GBAed7uL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cBacsJS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1F7M48aV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IvTr1Pgy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EagP9NdC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yLCqbHWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_63TKV5fr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NVgQci1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9qqf5Dv2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_H4po5inJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_68NjHvr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jphz34pt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vo09yqmu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vkz51DlS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2rIoGBMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VzoJk88G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_38RigMer_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nrNy9egC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CDWhbFsI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GetKtulG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eu4fwQng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_o2AT8vVf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pywUEQ7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LK3DZ7uI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QO8Fra90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jTUaqrlT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zo0LVyUX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KrzHegp9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ydus6JTM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NIiD4lHO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BqX9aQVj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qHWU7NPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CGcfobYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oZyTLofJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1X9AZkpo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tYLJLabe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D0AhBEmV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mKKab5dN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_boWG2BGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TXLHzFXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lYs1u2yp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v0qKr3R3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nLhUUVP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Mfyh6Jkh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RqXk7HFp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kOFgXuKV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tDn3Vqwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_avYjc6lh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gI16b6FR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fcfJemAr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rd6ceHGY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MN0sUlNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qt9TPyFJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_swPZtLmM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NWdgolne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2KeHf4Pi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B07vS4tw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kfpYar8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qz6HMaX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iMbltz1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l1eOeyc2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5kRdKQyx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LsGxICpX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KA3eKavm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3g7vK1dQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vJDi1PBz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HWUtQwxH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qbylboUM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_811Lq830_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5rnxzpOX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jTNeZT6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hsKedEgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ra5qEZYD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AtDBmiHj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UqOoh2Dg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_siGVLr3L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kI8O5KsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9lQgko5H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Q1dzeETv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aEJs6lFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_z1tnREq6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JBrQ2pCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z3fjvmjt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VFpZFFs1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4vd7eX79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_GB9Eu735_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GpyAKzaI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HxjtqIwd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5X801T9F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Rv7jOLpW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6gPNhATH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jVczoxPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X1nkq2bK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OVKkmlx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YbbGdoL2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_Gbpubkrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3XtXFyD9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HcvzLpPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k2qN8cXt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VcxqN7WN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FiF6YPXE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cuAiHwdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2EYUo4j6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0Xu1mtCs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hlca1ray_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xWW0ugil_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G6qfEkmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PGo7NNvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XQGmOUrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yUd5KMPu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_udhJSyqb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OXiX011J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jFsGmoSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_48FSa1nq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PD80oTTO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x80DeJw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PkGOW0tn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gG4LKErQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qaQWlNMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yWgjLti3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JmH4qmFE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_43K0CQk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hRzAWGSE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ekkeqHsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GLx9GYME_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WIYreUG1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M0LYhttJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qd47qgGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ufb5Z3Uq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EBHvKDnf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VvAcPbZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_awXBEHPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IeSWgOi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ijxVglpI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gnIv5SEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZleQHTYf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4iWAuMUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FOdvPwHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ht6Ln7LF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kZFkNTib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JlkVT1su_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Dz6Dlqxy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_q5LLOAi1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sMNbOaxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vc5n1j6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AqR5v8GT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AjJldCzf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4tWP0zSz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UYFiYAmS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QkiTDHAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6J36Zb5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uAiWRJwW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zG3Gzp8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_6ivbheIu;
  SignalLine sLine_bmMFvyAf;
  SignalTabhead sTabhead_ADCzZc2Y;
  SignalTabread sTabread_slNEcyeN;
  SignalTabread sTabread_iCoRGlk3;
  SignalLine sLine_h5Q1BSNL;
  SignalLine sLine_tAJeIkPX;
  SignalLine sLine_mQo83Lin;
  SignalTabhead sTabhead_WpOKz267;
  SignalTabread sTabread_XiqByUG5;
  SignalTabread sTabread_Q9w7b32A;
  SignalLine sLine_YywvXSKQ;
  SignalTabwrite sTabwrite_6fHMxiS0;
  SignalTabwrite sTabwrite_o8lqFoYA;
  SignalRPole sRPole_8omGyVtk;
  SignalRPole sRPole_duIWbG5J;
  SignalRPole sRPole_HEcqSUYW;
  SignalDel1 sDel1_oyIuzZKS;
  SignalLine sLine_uNYzm505;
  SignalLine sLine_6zmXEmRD;
  SignalRPole sRPole_IykCaCqH;
  SignalRPole sRPole_G7HcrwZQ;
  SignalRPole sRPole_HOmwoNzO;
  SignalDel1 sDel1_PHEEee2n;
  SignalLine sLine_do6qq7OJ;
  SignalLine sLine_k9p90COK;
  SignalLine sLine_QmdJoJrp;
  SignalLine sLine_6whyL3Ji;
  ControlVar cVar_jf8yzHoY;
  ControlVar cVar_BeK9uT5j;
  ControlVar cVar_xkumXSLm;
  ControlVar cVar_Kt2VGMSu;
  ControlSlice cSlice_BNMlPxFc;
  ControlVar cVar_4Jv0pIgZ;
  ControlSlice cSlice_JPpzNtYt;
  ControlVar cVar_LwrNG9rU;
  ControlSlice cSlice_0ALBEpBZ;
  ControlVar cVar_jw1W2xtV;
  ControlBinop cBinop_pWuZKubu;
  ControlBinop cBinop_T8qEyHcx;
  ControlBinop cBinop_sozQgNo7;
  ControlBinop cBinop_RPGPRkvm;
  ControlBinop cBinop_ri6nNmU6;
  ControlBinop cBinop_zrr79wMj;
  ControlBinop cBinop_ZluioeE1;
  ControlBinop cBinop_tcekbRzq;
  ControlBinop cBinop_13tY9fQD;
  ControlBinop cBinop_rgNL2Iy9;
  ControlBinop cBinop_CWN6rTPt;
  ControlBinop cBinop_rswrpnXm;
  ControlBinop cBinop_C8cR4o8p;
  ControlBinop cBinop_MwlvhSWA;
  ControlBinop cBinop_gOV4ww6T;
  ControlBinop cBinop_cyN4s6K9;
  ControlSlice cSlice_PL8p4tq4;
  ControlVar cVar_d3NQzdva;
  ControlDelay cDelay_JdJhPKco;
  ControlDelay cDelay_rdSw2V2v;
  ControlBinop cBinop_w9zkJeM7;
  HvTable hTable_NNeanlsA;
  ControlBinop cBinop_Ywt3UYgh;
  ControlDelay cDelay_RJl6USyL;
  ControlDelay cDelay_D9tiVKD3;
  ControlBinop cBinop_Of01aiZ7;
  HvTable hTable_MLxkKUal;
  ControlBinop cBinop_6ZlYxys8;
  ControlVar cVar_sBdp9Qrb;
  ControlBinop cBinop_VgXNw3Lq;
  ControlBinop cBinop_Z3tDj3H3;
  SignalVarf sVarf_Q24J1kyF;
  ControlBinop cBinop_2SpVg8XE;
  ControlBinop cBinop_BTdMnadb;
  ControlBinop cBinop_ELOt4cNW;
  SignalVarf sVarf_TswgYJEX;
  ControlVar cVar_jQfWluNR;
  ControlBinop cBinop_sCBImVAG;
  ControlBinop cBinop_GBAed7uL;
  SignalVarf sVarf_n65ZNFvw;
  ControlBinop cBinop_1F7M48aV;
  ControlBinop cBinop_IvTr1Pgy;
  ControlBinop cBinop_EagP9NdC;
  SignalVarf sVarf_tbApJojA;
  ControlBinop cBinop_yLCqbHWV;
  ControlBinop cBinop_63TKV5fr;
  SignalVarf sVarf_MnvQBLa5;
  ControlVar cVar_NVgQci1y;
  ControlBinop cBinop_68NjHvr6;
  ControlBinop cBinop_Jphz34pt;
  ControlBinop cBinop_Vkz51DlS;
  ControlBinop cBinop_2rIoGBMB;
  ControlBinop cBinop_VzoJk88G;
  ControlBinop cBinop_38RigMer;
  ControlBinop cBinop_nrNy9egC;
  SignalVarf sVarf_Qq2HDgiy;
  ControlVar cVar_eu4fwQng;
  ControlBinop cBinop_pywUEQ7G;
  ControlBinop cBinop_QO8Fra90;
  SignalVarf sVarf_u5zZ1U1i;
  SignalVarf sVarf_12khAXyZ;
  SignalVarf sVarf_m2gR5lFy;
  ControlVar cVar_KrzHegp9;
  ControlBinop cBinop_NIiD4lHO;
  ControlBinop cBinop_qHWU7NPM;
  SignalVarf sVarf_xWn2DdAV;
  SignalVarf sVarf_jWQgr8Cc;
  SignalVarf sVarf_Y3GsfxjC;
  ControlVar cVar_CGcfobYe;
  ControlBinop cBinop_tYLJLabe;
  ControlBinop cBinop_D0AhBEmV;
  SignalVarf sVarf_kIz15yLt;
  ControlBinop cBinop_boWG2BGu;
  ControlBinop cBinop_TXLHzFXi;
  ControlBinop cBinop_lYs1u2yp;
  SignalVarf sVarf_czBardnj;
  ControlVar cVar_v0qKr3R3;
  ControlBinop cBinop_RqXk7HFp;
  ControlBinop cBinop_kOFgXuKV;
  SignalVarf sVarf_4LYFf03k;
  ControlBinop cBinop_avYjc6lh;
  ControlBinop cBinop_gI16b6FR;
  ControlBinop cBinop_fcfJemAr;
  SignalVarf sVarf_UOk0J5Aa;
  ControlBinop cBinop_rd6ceHGY;
  ControlBinop cBinop_MN0sUlNI;
  SignalVarf sVarf_YdwtKnOs;
  ControlVar cVar_qt9TPyFJ;
  ControlBinop cBinop_2KeHf4Pi;
  ControlBinop cBinop_B07vS4tw;
  ControlBinop cBinop_Qz6HMaX8;
  ControlBinop cBinop_iMbltz1Y;
  ControlBinop cBinop_l1eOeyc2;
  ControlBinop cBinop_5kRdKQyx;
  ControlBinop cBinop_LsGxICpX;
  SignalVarf sVarf_0ztlcu6X;
  SignalVarf sVarf_WdoUL14E;
  SignalVarf sVarf_1Ao51fKB;
  ControlVar cVar_siGVLr3L;
  ControlBinop cBinop_kI8O5KsC;
  ControlIf cIf_9lQgko5H;
  ControlIf cIf_Q1dzeETv;
  ControlVar cVar_aEJs6lFt;
  ControlVar cVar_z1tnREq6;
  ControlVar cVar_JBrQ2pCA;
  ControlVar cVar_Z3fjvmjt;
  ControlSlice cSlice_4vd7eX79;
  ControlSlice cSlice_GB9Eu735;
  ControlVar cVar_GpyAKzaI;
  ControlIf cIf_HxjtqIwd;
  ControlBinop cBinop_6gPNhATH;
  ControlVar cVar_OVKkmlx5;
  ControlBinop cBinop_XQGmOUrH;
  ControlBinop cBinop_yUd5KMPu;
  ControlBinop cBinop_EBHvKDnf;
  ControlBinop cBinop_VvAcPbZb;
  ControlBinop cBinop_awXBEHPt;
  ControlBinop cBinop_gnIv5SEp;
  ControlBinop cBinop_ZleQHTYf;
  ControlBinop cBinop_4iWAuMUu;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
